<?php
/*
 * Enqueue admin stylesheet
 */
add_action('admin_enqueue_scripts', 'AGS_divi_podcast_load_wp_admin_style_theme');

function AGS_divi_podcast_load_wp_admin_style_theme()
{
    wp_enqueue_style('theme_wp_admin_css', get_stylesheet_directory_uri() . '/admin/css/admin.css', '', '1.1', '');
}

/*
 *  WP Dashboard Menu Items
 */

add_action('admin_menu', 'AGS_divi_podcast_admin_menu');

function AGS_divi_podcast_admin_menu()
{
    add_menu_page(
        esc_html__('Divi Podcast', 'divipodcast'),
        esc_html__('Divi Podcast', 'divipodcast'),
        'switch_themes',
        'AGS_child_theme',
        'AGS_divi_podcast_index'
    );
    add_submenu_page(
        'ags_divipodcast',
        esc_html__('Divi Podcast', 'divipodcast'),
        esc_html__('Theme Options', 'divipodcast'),
        'switch_themes',
        'AGS_child_theme',
        'AGS_divi_podcast_index'
    );
}

/*
 *  Admin Page, Demo Data Importer, Required Plugins
 */
/*
 * Include AGS Theme Updates
 */


add_action('after_setup_theme', 'AGS_THEME_updater');

function AGS_THEME_updater()
{
    if (is_admin()) {
        include(dirname(__FILE__) . '/updater/theme-updater.php');
        global $AGS_THEME_updater;
        if ($AGS_THEME_updater->has_license_key()) {
            
            @include(dirname(__FILE__) . '/aspen-plugin-installer/class-tgm-plugin-activation.php');
            
        }
    }
}


function AGS_divi_podcast_index()
{
    
    global $AGS_THEME_updater;
    if (!$AGS_THEME_updater->has_license_key()) {
        $AGS_THEME_updater->activate_page();
        return;
    }
    
    ?>
    <div id="ags-settings-container">
        <?php settings_errors(); ?>
        <div id="ags-settings">

            <div id="ags-settings-header">
                <div class="ags-settings-logo">
                    <h1><?php esc_html_e('Divi Podcast Child Theme', 'divipodcast') ?> </h1>
                </div>
                <div id="ags-settings-header-links">
                    <a id="ags-settings-header-link-support" href="https://support.aspengrovestudios.com/article/579-divi-podcast-child-theme"
                       target="_blank"><?php esc_html_e('Support', 'divipodcast') ?></a>
                </div>
            </div>
            <ul id="ags-settings-tabs">
                <li class="ags-settings-active"><a
                            href="#demo-content"><?php esc_html_e('Demo Content', 'divipodcast') ?></a></li>
                
                <li><a href="#license"><?php esc_html_e('License', 'divipodcast') ?></a></li>
                
            </ul>
            <div id="ags-settings-tabs-content">
                <div id="ags-settings-demo-content" class="ags-settings-active">
                    <div class="ags-settings-box">
                        <p>
                            <?php
                            $demo_url = 'https://divipodcast.aspengrovestudio.com/';
                            $anchor = esc_html__('This Demo', 'divipodcast');
                            $link = sprintf('<a href="%s" target="_blank" class="ags-import-demo-button button-primary">%s</a>', $demo_url, $anchor);
                            echo et_core_intentionally_unescaped(sprintf(esc_html__('Use  our built-in demo content tool. This will install the content and the design structure as shown in %1$s', 'divipodcast'), $link), 'html');
                            ?>

                        </p>
                        <h3><?php esc_html_e('The items that will be imported are:', 'divipodcast') ?></h3>
                        <ol>
                            <li><?php esc_html_e('Demo text content', 'divipodcast') ?></li>
                            <li><?php esc_html_e('Placeholder media files', 'divipodcast') ?></li>
                            <li><?php esc_html_e('Navigation Menu ', 'divipodcast') ?></li>
                            <li><?php esc_html_e('Demo posts, pages and products ', 'divipodcast') ?></li>
                            <li><?php esc_html_e('Site widgets (if applicable)', 'divipodcast') ?></li>
                        </ol>

                        <h3><?php esc_html_e('Please note: ', 'divipodcast') ?></h3>
                        <ol>
                            <li><?php esc_html_e('No WordPress settings will be imported.', 'divipodcast') ?></li>
                            <li><?php esc_html_e('No existing posts, pages, products, images, categories or any data will be modified or deleted.', 'divipodcast') ?>  </li>
                            <li><?php esc_html_e('The importer will install only placeholder images showing their usage dimension. You can refer to our demo site and replace the placeholder with your own images.', 'divipodcast') ?></li>
                        </ol>
                        <?php
                        // Check if WP Layouts plugin is active
                        // returns true if active
                        $wpl_status = in_array('wp-layouts/ags-layouts.php', apply_filters('active_plugins', get_option('active_plugins')));

                        if (!$wpl_status) {
                            echo '<div class="ags-settings-notice"> <p>';
                            // Translators: %s - links tag
                            printf(esc_html__('To import demo data, install and activate the latest version of the %sWP Layouts%s plugin', 'divi_ecommerce'),
                                '<a href="themes.php?page=tgmpa-install-plugins&plugin_status=activate">',
                                '</a>'
                            );
                            echo '</p></div>';
                        }
                        ?>
                        <button class="button-primary ags-import-demo-button" onclick="location.href='admin.php?page=ags-layouts-demo-import'" type="button" <?php echo $wpl_status ? '' : 'disabled' ?>><?php esc_html_e('Import Demo Data', 'divipodcast') ?></button>

                    </div>
                </div>
                
                <!-- LICENSE TAB -->
                <div id="ags-settings-license">
                    <div class="ags-settings-box">
                        <form method="post" action="options.php" id="AGS_THEME_license_form">
                            <?php $AGS_THEME_updater->license_key_box(); ?>
                        </form>
                    </div>
                </div>
                
            </div> <!-- close ags-settings-tabs-content -->
            <script>
                var ags_tabs_navigate = function () {
                    jQuery('#ags-settings-tabs-content > div, #ags-settings-tabs > li').removeClass('ags-settings-active');
                    jQuery('#ags-settings-' + location.hash.substr(1)).addClass('ags-settings-active');
                    jQuery('#ags-settings-tabs > li:has(a[href="' + location.hash + '"])').addClass('ags-settings-active');
                };
                if (location.hash) {
                    ags_tabs_navigate();
                }
                jQuery(window).on('hashchange', ags_tabs_navigate);
            </script>
        </div> <!-- close ags-settings -->
    </div> <!-- close ags-settings-container -->
    <?php
}

add_action('admin_init', 'AGS_divi_podcast_options');

function AGS_divi_podcast_options()
{
    register_setting(
        'AGS_divi_podcast_front_page_option',
        'AGS_divi_podcast_front_page_option'
    );
    add_settings_section(
        'AGS_divi_podcast_front_page',
        esc_html__('Import Demo Data', 'divi-health-clinic'),
        '',
        'AGS_divi_podcast_front_page_option'
    );
}



// List of required plugins
add_action('tgmpa_register', 'AGS_divi_podcast_require_plugins');

function AGS_divi_podcast_require_plugins()
{
    
    global $AGS_THEME_updater;
    if (!$AGS_THEME_updater->has_license_key()) {
        return;
    }
    

    $plugins = array(

        array(
            'name' => 'PowerPress Podcasting plugin by Blubrry',
            'slug' => 'powerpress',
            'required' => false,
            'force_activation' => false,
            'force_deactivation' => false
        ),
        array(
            'name' => 'WP Layouts',
            'slug' => 'wp-layouts',
            'required' => true,
            'force_activation' => false,
            'force_deactivation' => false
        ),
        array(
            'name' => 'GiveWP – Donation Plugin and Fundraising Platform',
            'slug' => 'give',
            'required' => false,
            'force_activation' => false,
            'force_deactivation' => false
        ),
        array(
            'name' => 'Popup Maker – Popup Forms, Opt-ins & More',
            'slug' => 'popup-maker',
            'required' => false,
            'force_activation' => false,
            'force_deactivation' => false
        ),
        array(
            'name' => 'The Events Calendar',
            'slug' => 'the-events-calendar',
            'required' => false,
            'force_activation' => false,
            'force_deactivation' => false
        ),
        array(
            'name' => 'User Registration – Custom Registration Form, Login And User Profile For WordPress',
            'slug' => 'user-registration',
            'required' => false,
            'force_activation' => false,
            'force_deactivation' => false
        ),
        array(
            'name' => 'WP-PageNavi',
            'slug' => 'wp-pagenavi',
            'required' => false,
            'force_activation' => false,
            'force_deactivation' => false
        )


    );
    tgmpa($plugins);
}


add_filter('ags_layouts_theme_demo_data', function() {
    
    global $AGS_THEME_updater;
    if (!$AGS_THEME_updater->has_license_key()) {
        $AGS_THEME_updater->activate_page();
        return;
    }
    
    return array (
        'layouts' =>
            array (
                5146 =>
                    array (
                        'name' => 'Divi Podcast',
                        'key' => 'lZFuT19aIo84WAI22MW9sy9OhImBgysl25L3NK7Ob91MdLlbRd',
                    ),
            ),
        'editor' => 'SiteImporter',
        'wplVersion' => '0.6.8',
    );
});