<?php

/*
 * Contains code copied from and/or based on Divi
 * See the license.txt file in the root directory for more information and licenses
 *
 */


/*
* Add new section to customizer
*/


function AGS_divi_podcast_customize_register($wp_customize)
{

    // Create panel
    $wp_customize->add_panel('ds_child_theme_customizer', array(
        'title' => esc_html__('Divi Podcast Child Theme Settings', 'divipodcast'),
        'priority' => 2,
    ));

    // Create sections
    $wp_customize->add_section('divi_child_theme_colors', array(
        'title' => __('Color Scheme', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 1,
        'description' => __('Color settings will be applied to your Divi Child Theme color scheme.', 'divipodcast'),
    ));

    $wp_customize->add_section('divi_child_theme_buttons', array(
        'title' => esc_html__('Button Settings', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 2,
        'description' => esc_html__('Settings set below will be applied to your Divi Child Theme buttons.', 'divipodcast'),
    ));

    $wp_customize->add_section('divi_child_theme_primary_button', array(
        'title' => __('Primary Button Color Scheme', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 3,
        'description' => __('Color settings below will be applied to primary buttons.', 'divipodcast'),
    ));

    $wp_customize->add_section('divi_child_theme_secondary_button', array(
        'title' => __('Secondary Button Color Scheme', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 4,
        'description' => __('Color settings below will be applied to secondary buttons.', 'divipodcast'),
    ));

    $wp_customize->add_section('divi_child_theme_blog', array(
        'title' => __('Blog Settings', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 5,
        'description' => __('Settings below will be applied to blog archives.', 'divipodcast'),
    ));

    $wp_customize->add_section('divi_child_theme_podcast', array(
        'title' => __('Podcast Settings', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 6,
        //   'description' => __('Settings below will be applied to podcast archives.', 'divipodcast'),
    ));

    $wp_customize->add_section('divi_child_theme_event', array(
        'title' => __('Event Settings', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 7,
        'description' => __('Settings below will be applied to event page.', 'divipodcast'),
    ));

    $wp_customize->add_section('divi_child_theme_misc', array(
        'title' => esc_html__('Miscellaneous', 'divipodcast'),
        'panel' => 'ds_child_theme_customizer',
        'priority' => 8,
    ));

    //radio box sanitization function
    function AGS_divi_podcast_sanitize_radio($input, $setting)
    {

        //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
        $input = sanitize_key($input);

        //get the list of possible radio box options
        $choices = $setting->manager->get_control($setting->id)->choices;

        //return input if valid or return default option
        return (array_key_exists($input, $choices) ? $input : $setting->default);

    }

    // --------------------------------------------------------------------------------------- //
    //                                       Color Scheme
    // --------------------------------------------------------------------------------------- //

    // Primary Accent Color
    $wp_customize->add_setting('divi_child_main_accent_color', array(
        'default' => '#ff1a9f',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_main_accent_color', //give it an ID
        array(
            'label' => esc_html__('Main Accent Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_main_accent_color' //pick the setting it applies to
        )
    ));

    // Second Accent Color
    $wp_customize->add_setting('divi_child_second_accent_color', array(
        'default' => '#0293f5',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_second_accent_color', //give it an ID
        array(
            'label' => esc_html__('Second Accent Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_second_accent_color' //pick the setting it applies to
        )
    ));

    // Third Accent Color
    $wp_customize->add_setting('divi_child_third_accent_color', array(
        'default' => '#010043',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_third_accent_color', //give it an ID
        array(
            'label' => esc_html__('Third Accent Color', 'divipodcast'), //set the label to appear in the Customizer
            'description' => esc_html__('Used as background color.', 'divipodcast'),
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_third_accent_color' //pick the setting it applies to
        )
    ));

    // Fourth Accent Color
    $wp_customize->add_setting('divi_child_fourth_accent_color', array(
        'default' => '#f6f7fb',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_fourth_accent_color', //give it an ID
        array(
            'label' => esc_html__('Light Grey Accent Color', 'divipodcast'), //set the label to appear in the Customizer
            'description' => esc_html__('Used as border background color.', 'divipodcast'),
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_fourth_accent_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_fifth_accent_color', array(
        'default' => '#e4e4e4',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_fifth_accent_color', //give it an ID
        array(
            'label' => __('Medium Grey Accent Color', 'divipodcast'), //set the label to appear in the Customizer
            'description' => esc_html__('Used as border and background color.', 'divipodcast'),
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_fifth_accent_color' //pick the setting it applies to
        )
    ));

    // Box Shadow Color
    $wp_customize->add_setting('divi_child_box_shadow_color_primary', array(
        'default' => 'rgba(255,26,159,0.8)',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_box_shadow_color_primary', //give it an ID
        array(
            'label' => esc_html__('Box Shadow Primary Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_box_shadow_color_primary' //pick the setting it applies to
        )
    ));

    // Box Shadow Color
    $wp_customize->add_setting('divi_child_box_shadow_color_secondary', array(
        'default' => '#0293f5',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_box_shadow_color_secondary', //give it an ID
        array(
            'label' => esc_html__('Box Shadow Secondary Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_box_shadow_color_secondary' //pick the setting it applies to
        )
    ));

    // Box Shadow Color
    $wp_customize->add_setting('divi_child_box_shadow_color_third', array(
        'default' => 'rgba(1,0,67,0.7)',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new ET_Divi_Customize_Color_Alpha_Control(
        $wp_customize,
        'divi_child_box_shadow_color_third', //give it an ID
        array(
            'label' => esc_html__('Box Shadow Third Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_colors', //select the section for it to appear under
            'settings' => 'divi_child_box_shadow_color_third' //pick the setting it applies to
        )
    ));

    // --------------------------------------------------------------------------------------- //
    //                                      Buttons
    // --------------------------------------------------------------------------------------- //

    $wp_customize->add_setting('divi_child_theme_button_text_size', array(
        'default' => '16',
        'type' => 'option',
        'transport' => 'refresh',
        'sanitize_callback' => 'absint',
    ));
    $wp_customize->add_control(new ET_Divi_Range_Option (
        $wp_customize,
        'divi_child_theme_button_text_size',
        array(
            'label' => esc_html__('Text size', 'divipodcast'),
            'section' => 'divi_child_theme_buttons',
            'settings' => 'divi_child_theme_button_text_size', //pick the setting it applies to
            'type' => 'range',
            'input_attrs' => array(
                'min' => 1,
                'max' => 30,
                'step' => 1
            ),
        )
    ));

    $wp_customize->add_setting('divi_child_theme_button_border_width', array(
        'default' => '2',
        'type' => 'option',
        'transport' => 'refresh',
        'sanitize_callback' => 'absint',
    ));
    $wp_customize->add_control(new ET_Divi_Range_Option (
        $wp_customize,
        'divi_child_theme_button_border_width',
        array(
            'label' => esc_html__('Border width', 'divipodcast'),
            'section' => 'divi_child_theme_buttons',
            'settings' => 'divi_child_theme_button_border_width', //pick the setting it applies to
            'type' => 'range',
            'input_attrs' => array(
                'min' => 0,
                'max' => 10,
                'step' => 1
            ),
        )
    ));

    $wp_customize->add_setting('divi_child_theme_button_radius', array(
        'default' => '30',
        'type' => 'option',
        'transport' => 'refresh',
        'sanitize_callback' => 'absint',
    ));
    $wp_customize->add_control(new ET_Divi_Range_Option (
        $wp_customize,
        'divi_child_theme_button_radius',
        array(
            'label' => esc_html__('Border radius', 'divipodcast'),
            'section' => 'divi_child_theme_buttons',
            'settings' => 'divi_child_theme_button_radius', //pick the setting it applies to
            'type' => 'range',
            'input_attrs' => array(
                'min' => 0,
                'max' => 50,
                'step' => 1
            ),
        )
    ));

    // Primary Button Color Scheme
    $wp_customize->add_setting('divi_child_theme_primary_button_text_color', array(
        'default' => '#ffffff',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_primary_button_text_color', //give it an ID
        array(
            'label' => __('Text Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_primary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_primary_button_text_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_primary_button_border_color', array(
        'default' => '#ff1a9f',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_primary_button_border_color', //give it an ID
        array(
            'label' => __('Border Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_primary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_primary_button_border_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_primary_button_background_color', array(
        'default' => '#ff1a9f',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_primary_button_background_color', //give it an ID
        array(
            'label' => __('Background Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_primary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_primary_button_background_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_primary_button_hover_text_color', array(
        'default' => '#ffffff',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_primary_button_hover_text_color', //give it an ID
        array(
            'label' => __('Hover Text Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_primary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_primary_button_hover_text_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_primary_button_hover_border_color', array(
        'default' => '#df0483',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_primary_button_hover_border_color', //give it an ID
        array(
            'label' => __('Hover Border Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_primary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_primary_button_hover_border_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_primary_button_hover_background_color', array(
        'default' => '#df0483',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_primary_button_hover_background_color', //give it an ID
        array(
            'label' => __('Hover Background Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_primary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_primary_button_hover_background_color' //pick the setting it applies to
        )
    ));

    // Secondary Button Color Scheme
    $wp_customize->add_setting('divi_child_theme_secondary_button_text_color', array(
        'default' => '#010043',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_secondary_button_text_color', //give it an ID
        array(
            'label' => __('Text Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_secondary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_secondary_button_text_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_secondary_button_border_color', array(
        'default' => '#ffffff',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_secondary_button_border_color', //give it an ID
        array(
            'label' => __('Border Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_secondary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_secondary_button_border_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_secondary_button_background_color', array(
        'default' => '#ffffff',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_secondary_button_background_color', //give it an ID
        array(
            'label' => __('Background Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_secondary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_secondary_button_background_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_secondary_button_hover_text_color', array(
        'default' => '#010043',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_secondary_button_hover_text_color', //give it an ID
        array(
            'label' => __('Hover Text Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_secondary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_secondary_button_hover_text_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_secondary_button_hover_border_color', array(
        'default' => '#f6f7fb',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_secondary_button_hover_border_color', //give it an ID
        array(
            'label' => __('Hover Border Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_secondary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_secondary_button_hover_border_color' //pick the setting it applies to
        )
    ));

    $wp_customize->add_setting('divi_child_theme_secondary_button_hover_background_color', array(
        'default' => '#f6f7fb',
        'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_post',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control(
        $wp_customize,
        'divi_child_theme_secondary_button_hover_background_color', //give it an ID
        array(
            'label' => __('Hover Background Color', 'divipodcast'), //set the label to appear in the Customizer
            'section' => 'divi_child_theme_secondary_button', //select the section for it to appear under
            'settings' => 'divi_child_theme_secondary_button_hover_background_color' //pick the setting it applies to
        )
    ));

    // --------------------------------------------------------------------------------------- //
    //                                      Blog Settings
    // --------------------------------------------------------------------------------------- //

    // Blog background image
    $wp_customize->add_setting('blog_bg_image', array(
        'default' => get_bloginfo('stylesheet_directory') . '/images/img-hero-blog.png',
        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'blog_bg_image', array(
        'label' => 'Background image',
        'section' => 'divi_child_theme_blog',
        'settings' => 'blog_bg_image',
        'description' => 'Choose a background image for blog page title section.',
    )));

    // Show / hide blog categories
    $wp_customize->add_setting('blog_cat_display', array(
        'default' => 'show',
        'transport' => 'refresh',
        'sanitize_callback' => 'AGS_divi_podcast_sanitize_radio',
    ));
    $wp_customize->add_control('blog_cat_display', array(
        'label' => 'Categories on Blog Archives',
        'section' => 'divi_child_theme_blog',
        'settings' => 'blog_cat_display',
        'type' => 'radio',
        'choices' => array(
            'show' => 'Show categories',
            'hide' => 'Hide categories',
        ),
    ));

    // Display blog sidebar
    $wp_customize->add_setting('blog_sidebar_display', array(
        'default' => 'hide',
        'transport' => 'refresh',
        'sanitize_callback' => 'AGS_divi_podcast_sanitize_radio',
    ));
    $wp_customize->add_control('blog_sidebar_display', array(
        'label' => 'Sidebar on Blog Archives',
        'section' => 'divi_child_theme_blog',
        'settings' => 'blog_sidebar_display',
        'type' => 'radio',
        'choices' => array(
            'show' => 'Show sidebar',
            'hide' => 'Hide sidebar',
        ),
    ));

    // Blog empty  thumb icon
    $wp_customize->add_setting('blog_no_thumb_icon', array(
        'default' => get_bloginfo('stylesheet_directory') . '/images/blog_no_thumb.png',
        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'blog_no_thumb_icon', array(
        'label' => 'Post without thumbnail',
        'section' => 'divi_child_theme_blog',
        'settings' => 'blog_no_thumb_icon',
        'description' => 'Choose "no thumbnail" icon for blog post. Recommended dimensions: 96x96px.',
    )));

    // --------------------------------------------------------------------------------------- //
    //                                      Podcast Settings
    // --------------------------------------------------------------------------------------- //

    // Podcast background image
    $wp_customize->add_setting('podcast_bg_image', array(
        'default' => get_bloginfo('stylesheet_directory') . '/images/img-hero-podcasts.png',
        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'podcast_bg_image', array(
        'label' => 'Background image',
        'section' => 'divi_child_theme_podcast',
        'settings' => 'podcast_bg_image',
        'description' => 'Choose a background image for podcast archives title section.',
    )));

    // Show / hide podcast categories
    $wp_customize->add_setting('podcast_tax_display', array(
        'default' => 'show',
        'transport' => 'refresh',
        'sanitize_callback' => 'AGS_divi_podcast_sanitize_radio',
    ));
    $wp_customize->add_control('podcast_tax_display', array(
        'label' => 'Categories on Podcast Archives',
        'section' => 'divi_child_theme_podcast',
        'settings' => 'podcast_tax_display',
        'type' => 'radio',
        'choices' => array(
            'show' => 'Show categories',
            'hide' => 'Hide categories',
        ),
    ));

    // Display podcast sidebar
    $wp_customize->add_setting('podcast_sidebar_display', array(
        'default' => 'hide',
        'transport' => 'refresh',
        'sanitize_callback' => 'AGS_divi_podcast_sanitize_radio',
    ));
    $wp_customize->add_control('podcast_sidebar_display', array(
        'label' => 'Sidebar on Podcast Archives',
        'section' => 'divi_child_theme_podcast',
        'settings' => 'podcast_sidebar_display',
        'type' => 'radio',
        'choices' => array(
            'show' => 'Show sidebar',
            'hide' => 'Hide sidebar',
        ),
    ));

    // Podcast play icon
    $wp_customize->add_setting('podcast_play_icon', array(
        'default' => get_bloginfo('stylesheet_directory') . '/images/play-icon.png',
        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'podcast_play_icon', array(
        'label' => 'Player play icon',
        'section' => 'divi_child_theme_podcast',
        'settings' => 'podcast_play_icon',
        'description' => 'Choose a play icon for podcast player. Recommended dimensions: 60x60px.',
    )));

    // Podcast stop icon
    $wp_customize->add_setting('podcast_stop_icon', array(
        'default' => get_bloginfo('stylesheet_directory') . '/images/stop-icon.png',
        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'podcast_stop_icon', array(
        'label' => 'Player stop icon',
        'section' => 'divi_child_theme_podcast',
        'settings' => 'podcast_stop_icon',
        'description' => 'Choose a stop icon for podcast player. Recommended dimensions: 60x60px.',
    )));

    // Podcast replay icon
    $wp_customize->add_setting('podcast_replay_icon', array(
        'default' => get_bloginfo('stylesheet_directory') . '/images/replay-icon.png',
        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'podcast_replay_icon', array(
        'label' => 'Player replay icon',
        'section' => 'divi_child_theme_podcast',
        'settings' => 'podcast_replay_icon',
        'description' => 'Choose a replay icon for podcast player. Recommended dimensions: 60x60px.',
    )));

    // --------------------------------------------------------------------------------------- //
    //                                      Event Settings
    // --------------------------------------------------------------------------------------- //
    
    // Event background image
    $wp_customize->add_setting('event_bg_image', array(
        'default' => get_bloginfo('stylesheet_directory') . '/images/img-hero-event.png',
        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'event_bg_image', array(
        'label' => 'Background image',
        'section' => 'divi_child_theme_event',
        'settings' => 'event_bg_image',
        'description' => 'Choose a background image for event page title section.',
    )));

    // --------------------------------------------------------------------------------------- //
    //                                       Miscellaneous
    // --------------------------------------------------------------------------------------- //

    // Border Radius
    $wp_customize->add_setting('divi_child_theme_border_radius', array(
        'default' => '8',
        'type' => 'option',
        'transport' => 'refresh',
        'sanitize_callback' => 'absint',
    ));
    $wp_customize->add_control(new ET_Divi_Range_Option (
        $wp_customize,
        'divi_child_theme_border_radius',
        array(
            'label' => esc_html__('Border radius (px)', 'divipodcast'),
            'section' => 'divi_child_theme_misc',
            'settings' => 'divi_child_theme_border_radius', //pick the setting it applies to
            'type' => 'range',
            'description' => esc_html__('General border radius applied to form elements, cards, boxes etc.', 'divipodcast'),
            'input_attrs' => array(
                'min' => 1,
                'max' => 50,
                'step' => 1
            ),
        )
    ));
}

add_action('customize_register', 'AGS_divi_podcast_customize_register');

/*
 * Output  custom settings CSS Style
 */

function AGS_divi_podcast_customize_css()
{

    /* ============================= */

    $main_accent = get_theme_mod('divi_child_main_accent_color', '#ff1a9f');
    $second_accent = get_theme_mod('divi_child_second_accent_color', '#0293f5');
    $third_accent = get_theme_mod('divi_child_third_accent_color', '#010043');
    $fourth_accent = get_theme_mod('divi_child_fourth_accent_color', '#f6f7fb');
    $fifth_accent = get_theme_mod('divi_child_fifth_accent_color', '#e4e4e4');

    $box_shadow_primary = get_theme_mod('divi_child_box_shadow_color_primary', 'rgba(255,26,159,0.8)');
    $box_shadow_secondary = get_theme_mod('divi_child_box_shadow_color_secondary', '#0293f5');
    $box_shadow_third = get_theme_mod('divi_child_box_shadow_color_third', 'rgba(1,0,67,0.7)');

    $border_radius = get_option('divi_child_theme_border_radius', '8') . "px";

    $button_border_width = get_option('divi_child_theme_button_border_width', '2') . "px";
    $button_radius = get_option('divi_child_theme_button_radius', '30') . "px";
    $button_text_size = get_option('divi_child_theme_button_text_size', '16') . "px";

    $primary_button_text_color = get_theme_mod('divi_child_theme_primary_button_text_color', '#ffffff');
    $primary_button_bg_color = get_theme_mod('divi_child_theme_primary_button_background_color', '#ff1a9f');
    $primary_button_border_color = get_theme_mod('divi_child_theme_primary_button_border_color', '#ff1a9f');
    $primary_button_hover_text_color = get_theme_mod('divi_child_theme_primary_button_hover_text_color', '#ffffff');
    $primary_button_hover_bg_color = get_theme_mod('divi_child_theme_primary_button_hover_background_color', '#df0483');
    $primary_button_hover_border_color = get_theme_mod('divi_child_theme_primary_button_hover_border_color', '#df0483');

    $secondary_button_text_color = get_theme_mod('divi_child_theme_secondary_button_text_color', '#010043');
    $secondary_button_bg_color = get_theme_mod('divi_child_theme_secondary_button_background_color', '#ffffff');
    $secondary_button_border_color = get_theme_mod('divi_child_theme_secondary_button_border_color', '#ffffff');
    $secondary_button_hover_text_color = get_theme_mod('divi_child_theme_secondary_button_hover_text_color', '#010043');
    $secondary_button_hover_bg_color = get_theme_mod('divi_child_theme_secondary_button_hover_background_color', '#f6f7fb');
    $secondary_button_hover_border_color = get_theme_mod('divi_child_theme_secondary_button_hover_border_color', '#f6f7fb');

    /* ============================= */

    ?>
    <style type="text/css">

        /*
         * Fifth Color Scheme
         */
        .medium-background-color, #sidebar .et_pb_widget.widget_search input[type=text], #sidebar .et_pb_widget.widget_search input[type=search], #sidebar .et_pb_widget.widget_product_search input[type=text], #sidebar .et_pb_widget.widget_product_search input[type=search], .divi-podcast-sidebar .et_pb_widget.widget_search input[type=text], .divi-podcast-sidebar .et_pb_widget.widget_search input[type=search], .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=text], .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=search], .et_pb_widget.widget_categories li a:hover, .et_pb_widget.widget_archive li a:hover, .divi-popup-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text], #tribe-events-content table.tribe-events-calendar td.tribe-events-future div[id*=tribe-events-daynum-], #tribe-events-content table.tribe-events-calendar td.tribe-events-future div[id*=tribe-events-daynum-] a, #user-registration.horizontal .user-registration-MyAccount-navigation ul li.is-active a, #commentform input[type=text], #commentform input[type=email], #commentform input[type=url], #commentform textarea, .divi-podcast-categories-list ul li.current-cat a {
            background-color: <?php esc_html_e($fifth_accent); ?> !important;
        }

        .medium-grey-color {
            color: <?php esc_html_e($fifth_accent); ?> !important;
        }

        .border-with-shadow, .medium-border-color, #sidebar .et_pb_widget.widget_search input[type=text], #sidebar .et_pb_widget.widget_search input[type=search], #sidebar .et_pb_widget.widget_product_search input[type=text], #sidebar .et_pb_widget.widget_product_search input[type=search], .divi-podcast-sidebar .et_pb_widget.widget_search input[type=text], .divi-podcast-sidebar .et_pb_widget.widget_search input[type=search], .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=text], .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=search], .divi-podcast-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text], .divi-popup-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text], .divi-podcast-toggle, .et-db #et-boc .divi-podcast-toggle, .divi-podcast-pricing-table .et_pb_featured_table, .give-form-wrap input.text, .give-form-wrap input.input-text, .give-form-wrap input.title, .give-form-wrap input[type=email], .give-form-wrap input[type=password], .give-form-wrap input[type=tel], .give-form-wrap input[type=text], .give-form-wrap select, .give-form input.text, .give-form input.input-text, .give-form input.title, .give-form input[type=email], .give-form input[type=password], .give-form input[type=tel], .give-form input[type=text], .give-form select, .give-form-wrap textarea, .give-form textarea, .divi-podcast-donationForm .give-donation-levels-wrap button.give-donation-level-btn, .mfp-content .give-donation-levels-wrap button.give-donation-level-btn, #give_donation_receipt, #give_user_history, #tribe-events input.text, #tribe-events input.input-text, #tribe-events input.title, #tribe-events input[type=email], #tribe-events input[type=password], #tribe-events input[type=tel], #tribe-events input[type=text], #tribe-events select, #tribe-bar-form input.text, #tribe-bar-form input.input-text, #tribe-bar-form input.title, #tribe-bar-form input[type=email], #tribe-bar-form input[type=password], #tribe-bar-form input[type=tel], #tribe-bar-form input[type=text], #tribe-bar-form select, #tribe-events textarea, #tribe-bar-form textarea, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner #tribe-bar-views-toggle, #tribe-events-content table.tribe-events-calendar, #tribe-events-content table.tribe-events-calendar td, .tribe-events-week-grid .tribe-events-grid, .tribe-events-week-grid .tribe-events-grid .tribe-scroller, .tribe-events-week-grid .tribe-events-grid .tribe-grid-content-wrap .column, .tribe-events-week-grid .tribe-events-grid .tribe-grid-allday, .tribe-events-week-grid .tribe-events-grid .tribe-week-grid-block div, .tribe-events-week-grid .tribe-events-grid .tribe-grid-allday .tribe-events-week-allday-single, .tribe-events-week-grid .tribe-events-grid .tribe-grid-body .tribe-events-week-hourly-single, .divi-podcast-powerpress-player .powerpress_embed_box input[type=text], .divi-podcast-subscribe-powerpress .pp-sub-widget input.pp-sub-m-i, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=email], .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=password], .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=tel], .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=text], .divi-podcast-subscribe-powerpress .pp-sub-widget select, .ur-frontend-form input.text, .ur-frontend-form input.input-text, .ur-frontend-form input.title, .ur-frontend-form input[type=email], .ur-frontend-form input[type=password], .ur-frontend-form input[type=tel], .ur-frontend-form input[type=text], .ur-frontend-form select, .ur-frontend-form textarea, #user-registration.horizontal .user-registration-MyAccount-navigation ul li a, .divi-podcast-contact-form input, .divi-podcast-contact-form p input, .divi-podcast-contact-form textarea, .divi-podcast-contact-form p textarea, ol.commentlist .comment .comment_avatar img, #commentform input[type=text], #commentform input[type=email], #commentform input[type=url], #commentform textarea, .divi-podcast-categories-list ul li a {
            border-color: <?php esc_html_e($fifth_accent); ?> !important;
        }

        /*
         * Fourth Color Scheme
         */
        .light-background-color, .wp-pagenavi a, .wp-pagenavi .nextpostslink, .wp-pagenavi .previouspostslink, .notice-dismiss, .divi-podcast-donationForm .give-donation-levels-wrap button.give-donation-level-btn.give-default-level, .mfp-content .give-donation-levels-wrap button.give-donation-level-btn.give-default-level, .tribe-events-notices, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner .tribe-bar-views-list, #tribe-bar-form.tribe-bar-collapse .tribe-bar-filters, .tribe-events-list .type-tribe_events, #tribe-events-content table.tribe-events-calendar div[id*=tribe-events-daynum-], #tribe-events-content table.tribe-events-calendar div[id*=tribe-events-daynum-] a, #tribe-events-content table.tribe-events-calendar td:hover, #tribe-mobile-container .type-tribe_events, .tribe-events-week-grid .tribe-events-grid .tribe-grid-allday, .tribe-events-week-grid .tribe-events-grid .tribe-grid-body .tribe-events-week-hourly-single, .user-registration-info, .divi-podcast-blog-box .post-wrapper, .post-type-archive-podcast #main-content, .tax-podcast-category #main-content, .pct-related-podcasts {
            background-color: <?php esc_html_e($fourth_accent); ?> !important;
        }

        .light-grey-color {
            color: <?php esc_html_e($fourth_accent); ?> !important;
        }

        .light-border-color, .mobile_nav ul.et_mobile_menu li a, .divi-podcast-menuPrimary ul.et_mobile_menu li a, #sidebar .et_pb_widget.widget_recent_comments ul li, #sidebar .et_pb_widget.widget_recent_entries ul li, .divi-podcast-sidebar .et_pb_widget.widget_recent_comments ul li, .divi-podcast-sidebar .et_pb_widget.widget_recent_entries ul li, .tribe-organizer-wrapper .organizer-avatar, .divi-podcast-blog-box .author-info img {
            border-color: <?php esc_html_e($fourth_accent); ?> !important;
        }

        /*
         * Third Color Scheme
         */
        .dark-background-color, .divi-podcast-overlay:before, #sidebar .et_pb_widget.widget_tag_cloud .tagcloud a, .divi-podcast-sidebar .et_pb_widget.widget_tag_cloud .tagcloud a, .index-archive-header, .divi-podcast-event-top, .divi-podcast-event-top .event-overlay, .divi-podcast-blog-box .thumb-wrapper.no-thumbnail {
            background-color: <?php esc_html_e($third_accent); ?> !important;
        }

        .dark-color, .dark-link-hover-color a:hover, .dark-link-color a, #sidebar .et_pb_widget.widget_search input[type=text], #sidebar .et_pb_widget.widget_search input[type=search], #sidebar .et_pb_widget.widget_product_search input[type=text], #sidebar .et_pb_widget.widget_product_search input[type=search], .divi-podcast-sidebar .et_pb_widget.widget_search input[type=text], .divi-podcast-sidebar .et_pb_widget.widget_search input[type=search], .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=text], .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=search], #sidebar .et_pb_widget.widget_search input[type=text]::-webkit-input-placeholder, #sidebar .et_pb_widget.widget_search input[type=search]::-webkit-input-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=text]::-webkit-input-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=search]::-webkit-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=text]::-webkit-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=search]::-webkit-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=text]::-webkit-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=search]::-webkit-input-placeholder, #sidebar .et_pb_widget.widget_search input[type=text]:-ms-input-placeholder, #sidebar .et_pb_widget.widget_search input[type=search]:-ms-input-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=text]:-ms-input-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=search]:-ms-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=text]:-ms-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=search]:-ms-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=text]:-ms-input-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=search]:-ms-input-placeholder, #sidebar .et_pb_widget.widget_search input[type=text]::-moz-placeholder, #sidebar .et_pb_widget.widget_search input[type=search]::-moz-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=text]::-moz-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=search]::-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=text]::-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=search]::-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=text]::-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=search]::-moz-placeholder, #sidebar .et_pb_widget.widget_search input[type=text]:-moz-placeholder, #sidebar .et_pb_widget.widget_search input[type=search]:-moz-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=text]:-moz-placeholder, #sidebar .et_pb_widget.widget_product_search input[type=search]:-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=text]:-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_search input[type=search]:-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=text]:-moz-placeholder, .divi-podcast-sidebar .et_pb_widget.widget_product_search input[type=search]:-moz-placeholder, .divi-podcast-newsletter .et_pb_newsletter_result .et_pb_newsletter_error, .divi-popup-newsletter .et_pb_newsletter_result .et_pb_newsletter_error, .divi-podcast-newsletter .et_pb_newsletter_result .et_pb_newsletter_success, .divi-popup-newsletter .et_pb_newsletter_result .et_pb_newsletter_success, .divi-podcast-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text], .divi-podcast-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]::-webkit-input-placeholder, .divi-podcast-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]:-ms-input-placeholder, .divi-podcast-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]::-moz-placeholder, .divi-podcast-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]:-moz-placeholder, .divi-popup-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text], .divi-popup-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]::-webkit-input-placeholder, .divi-popup-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]:-ms-input-placeholder, .divi-popup-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]::-moz-placeholder, .divi-popup-newsletter .et_pb_newsletter_form p.et_pb_newsletter_field input[type=text]:-moz-placeholder, .divi-podcast-toggle .et_pb_toggle_title, .divi-podcast-toggle h5.et_pb_toggle_title, .et-db #et-boc .divi-podcast-toggle .et_pb_toggle_title, .et-db #et-boc .divi-podcast-toggle h5.et_pb_toggle_title, .et-db #et-boc .divi-podcast-search.et_pb_search input.et_pb_s, .divi-podcast-search.et_pb_search input.et_pb_s, .et-db #et-boc .divi-podcast-search.et_pb_search input.et_pb_s::-webkit-input-placeholder, .divi-podcast-search.et_pb_search input.et_pb_s::-webkit-input-placeholder, .et-db #et-boc .divi-podcast-search.et_pb_search input.et_pb_s:-ms-input-placeholder, .divi-podcast-search.et_pb_search input.et_pb_s:-ms-input-placeholder, .et-db #et-boc .divi-podcast-search.et_pb_search input.et_pb_s::-moz-placeholder, .divi-podcast-search.et_pb_search input.et_pb_s::-moz-placeholder, .et-db #et-boc .divi-podcast-search.et_pb_search input.et_pb_s:-moz-placeholder, .divi-podcast-search.et_pb_search input.et_pb_s:-moz-placeholder, .give-form-wrap input.text, .give-form-wrap input.input-text, .give-form-wrap input.title, .give-form-wrap input[type=email], .give-form-wrap input[type=password], .give-form-wrap input[type=tel], .give-form-wrap input[type=text], .give-form-wrap select, .give-form input.text, .give-form input.input-text, .give-form input.title, .give-form input[type=email], .give-form input[type=password], .give-form input[type=tel], .give-form input[type=text], .give-form select, .give-form-wrap input.text::-webkit-input-placeholder, .give-form-wrap input.input-text::-webkit-input-placeholder, .give-form-wrap input.title::-webkit-input-placeholder, .give-form-wrap input[type=email]::-webkit-input-placeholder, .give-form-wrap input[type=password]::-webkit-input-placeholder, .give-form-wrap input[type=tel]::-webkit-input-placeholder, .give-form-wrap input[type=text]::-webkit-input-placeholder, .give-form-wrap select::-webkit-input-placeholder, .give-form input.text::-webkit-input-placeholder, .give-form input.input-text::-webkit-input-placeholder, .give-form input.title::-webkit-input-placeholder, .give-form input[type=email]::-webkit-input-placeholder, .give-form input[type=password]::-webkit-input-placeholder, .give-form input[type=tel]::-webkit-input-placeholder, .give-form input[type=text]::-webkit-input-placeholder, .give-form select::-webkit-input-placeholder, .give-form-wrap input.text:-ms-input-placeholder, .give-form-wrap input.input-text:-ms-input-placeholder, .give-form-wrap input.title:-ms-input-placeholder, .give-form-wrap input[type=email]:-ms-input-placeholder, .give-form-wrap input[type=password]:-ms-input-placeholder, .give-form-wrap input[type=tel]:-ms-input-placeholder, .give-form-wrap input[type=text]:-ms-input-placeholder, .give-form-wrap select:-ms-input-placeholder, .give-form input.text:-ms-input-placeholder, .give-form input.input-text:-ms-input-placeholder, .give-form input.title:-ms-input-placeholder, .give-form input[type=email]:-ms-input-placeholder, .give-form input[type=password]:-ms-input-placeholder, .give-form input[type=tel]:-ms-input-placeholder, .give-form input[type=text]:-ms-input-placeholder, .give-form select:-ms-input-placeholder, .give-form-wrap input.text::-moz-placeholder, .give-form-wrap input.input-text::-moz-placeholder, .give-form-wrap input.title::-moz-placeholder, .give-form-wrap input[type=email]::-moz-placeholder, .give-form-wrap input[type=password]::-moz-placeholder, .give-form-wrap input[type=tel]::-moz-placeholder, .give-form-wrap input[type=text]::-moz-placeholder, .give-form-wrap select::-moz-placeholder, .give-form input.text::-moz-placeholder, .give-form input.input-text::-moz-placeholder, .give-form input.title::-moz-placeholder, .give-form input[type=email]::-moz-placeholder, .give-form input[type=password]::-moz-placeholder, .give-form input[type=tel]::-moz-placeholder, .give-form input[type=text]::-moz-placeholder, .give-form select::-moz-placeholder, .give-form-wrap input.text:-moz-placeholder, .give-form-wrap input.input-text:-moz-placeholder, .give-form-wrap input.title:-moz-placeholder, .give-form-wrap input[type=email]:-moz-placeholder, .give-form-wrap input[type=password]:-moz-placeholder, .give-form-wrap input[type=tel]:-moz-placeholder, .give-form-wrap input[type=text]:-moz-placeholder, .give-form-wrap select:-moz-placeholder, .give-form input.text:-moz-placeholder, .give-form input.input-text:-moz-placeholder, .give-form input.title:-moz-placeholder, .give-form input[type=email]:-moz-placeholder, .give-form input[type=password]:-moz-placeholder, .give-form input[type=tel]:-moz-placeholder, .give-form input[type=text]:-moz-placeholder, .give-form select:-moz-placeholder, .give-form-wrap textarea, .give-form textarea, .give-form-wrap textarea::-webkit-input-placeholder, .give-form textarea::-webkit-input-placeholder, .give-form-wrap textarea:-ms-input-placeholder, .give-form textarea:-ms-input-placeholder, .give-form-wrap textarea::-moz-placeholder, .give-form textarea::-moz-placeholder, .give-form-wrap textarea:-moz-placeholder, .give-form textarea:-moz-placeholder, .give_error, .notice-dismiss, .give_success, .give_warning, #tribe-events input.text, #tribe-events input.input-text, #tribe-events input.title, #tribe-events input[type=email], #tribe-events input[type=password], #tribe-events input[type=tel], #tribe-events input[type=text], #tribe-events select, #tribe-bar-form input.text, #tribe-bar-form input.input-text, #tribe-bar-form input.title, #tribe-bar-form input[type=email], #tribe-bar-form input[type=password], #tribe-bar-form input[type=tel], #tribe-bar-form input[type=text], #tribe-bar-form select, #tribe-events input.text::-webkit-input-placeholder, #tribe-events input.input-text::-webkit-input-placeholder, #tribe-events input.title::-webkit-input-placeholder, #tribe-events input[type=email]::-webkit-input-placeholder, #tribe-events input[type=password]::-webkit-input-placeholder, #tribe-events input[type=tel]::-webkit-input-placeholder, #tribe-events input[type=text]::-webkit-input-placeholder, #tribe-events select::-webkit-input-placeholder, #tribe-bar-form input.text::-webkit-input-placeholder, #tribe-bar-form input.input-text::-webkit-input-placeholder, #tribe-bar-form input.title::-webkit-input-placeholder, #tribe-bar-form input[type=email]::-webkit-input-placeholder, #tribe-bar-form input[type=password]::-webkit-input-placeholder, #tribe-bar-form input[type=tel]::-webkit-input-placeholder, #tribe-bar-form input[type=text]::-webkit-input-placeholder, #tribe-bar-form select::-webkit-input-placeholder, #tribe-events input.text:-ms-input-placeholder, #tribe-events input.input-text:-ms-input-placeholder, #tribe-events input.title:-ms-input-placeholder, #tribe-events input[type=email]:-ms-input-placeholder, #tribe-events input[type=password]:-ms-input-placeholder, #tribe-events input[type=tel]:-ms-input-placeholder, #tribe-events input[type=text]:-ms-input-placeholder, #tribe-events select:-ms-input-placeholder, #tribe-bar-form input.text:-ms-input-placeholder, #tribe-bar-form input.input-text:-ms-input-placeholder, #tribe-bar-form input.title:-ms-input-placeholder, #tribe-bar-form input[type=email]:-ms-input-placeholder, #tribe-bar-form input[type=password]:-ms-input-placeholder, #tribe-bar-form input[type=tel]:-ms-input-placeholder, #tribe-bar-form input[type=text]:-ms-input-placeholder, #tribe-bar-form select:-ms-input-placeholder, #tribe-events input.text::-moz-placeholder, #tribe-events input.input-text::-moz-placeholder, #tribe-events input.title::-moz-placeholder, #tribe-events input[type=email]::-moz-placeholder, #tribe-events input[type=password]::-moz-placeholder, #tribe-events input[type=tel]::-moz-placeholder, #tribe-events input[type=text]::-moz-placeholder, #tribe-events select::-moz-placeholder, #tribe-bar-form input.text::-moz-placeholder, #tribe-bar-form input.input-text::-moz-placeholder, #tribe-bar-form input.title::-moz-placeholder, #tribe-bar-form input[type=email]::-moz-placeholder, #tribe-bar-form input[type=password]::-moz-placeholder, #tribe-bar-form input[type=tel]::-moz-placeholder, #tribe-bar-form input[type=text]::-moz-placeholder, #tribe-bar-form select::-moz-placeholder, #tribe-events input.text:-moz-placeholder, #tribe-events input.input-text:-moz-placeholder, #tribe-events input.title:-moz-placeholder, #tribe-events input[type=email]:-moz-placeholder, #tribe-events input[type=password]:-moz-placeholder, #tribe-events input[type=tel]:-moz-placeholder, #tribe-events input[type=text]:-moz-placeholder, #tribe-events select:-moz-placeholder, #tribe-bar-form input.text:-moz-placeholder, #tribe-bar-form input.input-text:-moz-placeholder, #tribe-bar-form input.title:-moz-placeholder, #tribe-bar-form input[type=email]:-moz-placeholder, #tribe-bar-form input[type=password]:-moz-placeholder, #tribe-bar-form input[type=tel]:-moz-placeholder, #tribe-bar-form input[type=text]:-moz-placeholder, #tribe-bar-form select:-moz-placeholder, #tribe-events textarea, #tribe-bar-form textarea, #tribe-events textarea::-webkit-input-placeholder, #tribe-bar-form textarea::-webkit-input-placeholder, #tribe-events textarea:-ms-input-placeholder, #tribe-bar-form textarea:-ms-input-placeholder, #tribe-events textarea::-moz-placeholder, #tribe-bar-form textarea::-moz-placeholder, #tribe-events textarea:-moz-placeholder, #tribe-bar-form textarea:-moz-placeholder, .give_error, .tribe-events-notices, .give_success, .give_warning, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner #tribe-bar-views-toggle, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner #tribe-bar-views-toggle::-webkit-input-placeholder, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner #tribe-bar-views-toggle:-ms-input-placeholder, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner #tribe-bar-views-toggle::-moz-placeholder, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner #tribe-bar-views-toggle:-moz-placeholder, .divi-podcast-powerpress-player .powerpress_embed_box input[type=text], .divi-podcast-powerpress-player .powerpress_embed_box input[type=text]::-webkit-input-placeholder, .divi-podcast-powerpress-player .powerpress_embed_box input[type=text]:-ms-input-placeholder, .divi-podcast-powerpress-player .powerpress_embed_box input[type=text]::-moz-placeholder, .divi-podcast-powerpress-player .powerpress_embed_box input[type=text]:-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input.pp-sub-m-i, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=email], .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=password], .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=tel], .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=text], .divi-podcast-subscribe-powerpress .pp-sub-widget select, .divi-podcast-subscribe-powerpress .pp-sub-widget input.pp-sub-m-i::-webkit-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=email]::-webkit-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=password]::-webkit-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=tel]::-webkit-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=text]::-webkit-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget select::-webkit-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input.pp-sub-m-i:-ms-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=email]:-ms-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=password]:-ms-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=tel]:-ms-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=text]:-ms-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget select:-ms-input-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input.pp-sub-m-i::-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=email]::-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=password]::-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=tel]::-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=text]::-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget select::-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input.pp-sub-m-i:-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=email]:-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=password]:-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=tel]:-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget input[type=text]:-moz-placeholder, .divi-podcast-subscribe-powerpress .pp-sub-widget select:-moz-placeholder, .ur-frontend-form input.text, .ur-frontend-form input.input-text, .ur-frontend-form input.title, .ur-frontend-form input[type=email], .ur-frontend-form input[type=password], .ur-frontend-form input[type=tel], .ur-frontend-form input[type=text], .ur-frontend-form select, .ur-frontend-form input.text::-webkit-input-placeholder, .ur-frontend-form input.input-text::-webkit-input-placeholder, .ur-frontend-form input.title::-webkit-input-placeholder, .ur-frontend-form input[type=email]::-webkit-input-placeholder, .ur-frontend-form input[type=password]::-webkit-input-placeholder, .ur-frontend-form input[type=tel]::-webkit-input-placeholder, .ur-frontend-form input[type=text]::-webkit-input-placeholder, .ur-frontend-form select::-webkit-input-placeholder, .ur-frontend-form input.text:-ms-input-placeholder, .ur-frontend-form input.input-text:-ms-input-placeholder, .ur-frontend-form input.title:-ms-input-placeholder, .ur-frontend-form input[type=email]:-ms-input-placeholder, .ur-frontend-form input[type=password]:-ms-input-placeholder, .ur-frontend-form input[type=tel]:-ms-input-placeholder, .ur-frontend-form input[type=text]:-ms-input-placeholder, .ur-frontend-form select:-ms-input-placeholder, .ur-frontend-form input.text::-moz-placeholder, .ur-frontend-form input.input-text::-moz-placeholder, .ur-frontend-form input.title::-moz-placeholder, .ur-frontend-form input[type=email]::-moz-placeholder, .ur-frontend-form input[type=password]::-moz-placeholder, .ur-frontend-form input[type=tel]::-moz-placeholder, .ur-frontend-form input[type=text]::-moz-placeholder, .ur-frontend-form select::-moz-placeholder, .ur-frontend-form input.text:-moz-placeholder, .ur-frontend-form input.input-text:-moz-placeholder, .ur-frontend-form input.title:-moz-placeholder, .ur-frontend-form input[type=email]:-moz-placeholder, .ur-frontend-form input[type=password]:-moz-placeholder, .ur-frontend-form input[type=tel]:-moz-placeholder, .ur-frontend-form input[type=text]:-moz-placeholder, .ur-frontend-form select:-moz-placeholder, .ur-frontend-form textarea, .ur-frontend-form textarea::-webkit-input-placeholder, .ur-frontend-form textarea:-ms-input-placeholder, .ur-frontend-form textarea::-moz-placeholder, .ur-frontend-form textarea:-moz-placeholder, .user-registration-error, .user-registration-info, .user-registration-message, .divi-podcast-contact-form input, .divi-podcast-contact-form p input, .divi-podcast-contact-form input::-webkit-input-placeholder, .divi-podcast-contact-form p input::-webkit-input-placeholder, .divi-podcast-contact-form input:-ms-input-placeholder, .divi-podcast-contact-form p input:-ms-input-placeholder, .divi-podcast-contact-form input::-moz-placeholder, .divi-podcast-contact-form p input::-moz-placeholder, .divi-podcast-contact-form input:-moz-placeholder, .divi-podcast-contact-form p input:-moz-placeholder, .divi-podcast-contact-form textarea, .divi-podcast-contact-form p textarea, .divi-podcast-contact-form textarea::-webkit-input-placeholder, .divi-podcast-contact-form p textarea::-webkit-input-placeholder, .divi-podcast-contact-form textarea:-ms-input-placeholder, .divi-podcast-contact-form p textarea:-ms-input-placeholder, .divi-podcast-contact-form textarea::-moz-placeholder, .divi-podcast-contact-form p textarea::-moz-placeholder, .divi-podcast-contact-form textarea:-moz-placeholder, .divi-podcast-contact-form p textarea:-moz-placeholder, #commentform input[type=text], #commentform input[type=email], #commentform input[type=url], #commentform input[type=text]::-webkit-input-placeholder, #commentform input[type=email]::-webkit-input-placeholder, #commentform input[type=url]::-webkit-input-placeholder, #commentform input[type=text]:-ms-input-placeholder, #commentform input[type=email]:-ms-input-placeholder, #commentform input[type=url]:-ms-input-placeholder, #commentform input[type=text]::-moz-placeholder, #commentform input[type=email]::-moz-placeholder, #commentform input[type=url]::-moz-placeholder, #commentform input[type=text]:-moz-placeholder, #commentform input[type=email]:-moz-placeholder, #commentform input[type=url]:-moz-placeholder, #commentform textarea, #commentform textarea::-webkit-input-placeholder, #commentform textarea:-ms-input-placeholder, #commentform textarea::-moz-placeholder, #commentform textarea:-moz-placeholder, .divi-podcast-toggle .et_pb_toggle_content, .et-db #et-boc .divi-podcast-toggle .et_pb_toggle_content, .divi-podcast-pricing-table .et_pb_featured_table, .divi-podcast-pricing-table .et_pb_featured_table .et_pb_et_price, .divi-podcast-pricing-table .et_pb_featured_table .et_pb_pricing_title, .give-form-wrap label, .give-form label, #tribe-events label, #tribe-bar-form label, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner #tribe-bar-views-toggle:after, .ur-frontend-form label, .divi-podcast-contact-form label {
            color: <?php esc_html_e($third_accent); ?> !important;
        }

        .dark-border-color {
            border-color: <?php esc_html_e($third_accent); ?> !important;
        }

        /*
         * Second Color Scheme
         */
        .secondary-background-color, #give_donation_receipt thead th, #give_user_history thead th, .divi-podcast-event-top .tribe-events-cost, #tribe-events-photo-events .tribe-events-photo-event .event-photo-thumb-wrapper .tribe-events-event-cost .ticket-cost, .tribe-events-list .type-tribe_events .event-thumb-wrapper .tribe-events-event-cost .ticket-cost, #tribe-events-content table.tribe-events-calendar thead th, .tribe-events-week-grid .tribe-events-grid .tribe-grid-header, #tribe-events .tribe-events-button, .tribe-events-list .type-tribe_events.tribe-event-featured, .tribe-events-list .type-tribe_events.tribe-event-featured {
            background-color: <?php esc_html_e($second_accent); ?> !important;
        }

        .secondary-link-color a, .secondary-link-hover-color a:hover, .secondary-color, .podcast-box .podcast-box-meta .post-meta a, .divi-podcast-toggle .et_pb_toggle_title:before, .divi-podcast-toggle h5.et_pb_toggle_title:before, .et-db #et-boc .divi-podcast-toggle .et_pb_toggle_title:before, .et-db #et-boc .divi-podcast-toggle h5.et_pb_toggle_title:before, .divi-podcast-blog-box .blog-box-meta .post-meta a, .tribe-events-list .type-tribe_events:not(.tribe-event-featured) a.tribe-events-gmap {
            color: <?php esc_html_e($second_accent); ?> !important;
        }

        .secondary-border-color {
            border-color: <?php esc_html_e($second_accent); ?> !important;
        }

        /*
         * First Color Scheme
         */
        .primary-background-color, .primary-background-color, #sidebar .et_pb_widget.widget_tag_cloud .tagcloud a:hover, .divi-podcast-sidebar .et_pb_widget.widget_tag_cloud .tagcloud a:hover, #sidebar .et_pb_widget.widget_tag_cloud .tagcloud a:hover, .divi-podcast-sidebar .et_pb_widget.widget_tag_cloud .tagcloud a:hover, .divi-podcast-tabs ul.et_pb_tabs_controls li.et_pb_tab_active a, .divi-podcast-tabs ul.et_pb_tabs_controls li a:hover, .divi-podcast-tabs ul.et_pb_tabs_controls li.et_pb_tab_active a, .divi-podcast-tabs ul.et_pb_tabs_controls li a:hover, .wp-pagenavi a:hover, .wp-pagenavi .nextpostslink:hover, .wp-pagenavi .previouspostslink:hover, .wp-pagenavi a:hover, .wp-pagenavi .nextpostslink:hover, .wp-pagenavi .previouspostslink:hover, .wp-pagenavi span.current, .wp-pagenavi span.current, .divi-podcast-event-top .tribe-events-cost.free-ticket, .divi-podcast-event-top .tribe-events-cost.free-ticket, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner .tribe-bar-views-list .tribe-bar-views-option.tribe-bar-active, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner .tribe-bar-views-list .tribe-bar-views-option.tribe-bar-active, #tribe-bar-form #tribe-bar-collapse-toggle.tribe-bar-filters-open, #tribe-bar-form #tribe-bar-collapse-toggle.tribe-bar-filters-open, #tribe-events-photo-events .tribe-events-photo-event .event-photo-thumb-wrapper .tribe-events-event-cost .ticket-cost.free-ticket, #tribe-events-photo-events .tribe-events-photo-event .event-photo-thumb-wrapper .tribe-events-event-cost .ticket-cost.free-ticket, .tribe-events-list .type-tribe_events .event-thumb-wrapper .tribe-events-event-cost .ticket-cost.free-ticket, .tribe-events-list .type-tribe_events .event-thumb-wrapper .tribe-events-event-cost .ticket-cost.free-ticket, #tribe-events-content table.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-], #tribe-events-content table.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-] a, #tribe-events-content table.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-], #tribe-events-content table.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-] a, #tribe-mobile-container .tribe-mobile-day-date, #tribe-mobile-container .tribe-mobile-day-date, .tribe-events-day .tribe-events-day-time-slot .tribe-events-day-time-slot-heading, .tribe-events-day .tribe-events-day-time-slot .tribe-events-day-time-slot-heading {
            background-color: <?php esc_html_e($main_accent); ?> !important;
        }

        .primary-link-color a, .primary-link-hover-color a:hover, .primary-color, .divi-podcast-lines-menu li.menu-item.menu-item-has-children > a:after, .divi-podcast-menuPrimary ul.et-menu > li.menu-item > a:hover, .divi-podcast-menuPrimary ul.et-menu > li.menu-item.menu-item-has-children > a:after, .divi-podcast-menuPrimary ul.et-menu > li.menu-item.current-menu-item > a, .divi-podcast-tabs ul.et_pb_tabs_controls li a, #tribe-events-photo-events .tribe-events-photo-event h2.tribe-events-list-event-title:hover, .tribe-events-list .type-tribe_events .event-content-wrapper h2.tribe-events-map-event-title:hover, .tribe-events-list .type-tribe_events .event-content-wrapper h3.tribe-events-list-event-title:hover, .divi-podcast-subscribe-powerpress .pp-sub-widget div.pp-sub-t, .divi-podcast-menuPrimary .et-menu-nav li.mega-menu > ul > li > a:first-child, .mobile_nav ul.et_mobile_menu li a:hover, .divi-podcast-menuPrimary ul.et_mobile_menu li a:hover, #main-header .et_mobile_menu .menu-item-has-children > a:after, .divi-podcast-footerMenuWidget ul li a:hover, #sidebar .et_pb_widget.widget_recent_comments ul li a:hover, #sidebar .et_pb_widget.widget_recent_entries ul li a:hover, .divi-podcast-sidebar .et_pb_widget.widget_recent_comments ul li a:hover, .divi-podcast-sidebar .et_pb_widget.widget_recent_entries ul li a:hover, .notice-dismiss a, .divi-podcast-donationForm .give-donation-levels-wrap button.give-donation-level-btn:not(.give-default-level):hover, .mfp-content .give-donation-levels-wrap button.give-donation-level-btn:not(.give-default-level):hover, .divi-podcast-donationForm #give-final-total-wrap span.give-final-total-amount, .mfp-content #give-final-total-wrap span.give-final-total-amount, .tribe-events-notices a, .divi-podcast-event-content .tribe-events-event-meta .tribe-events-meta-group a:hover, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner .tribe-bar-views-list .tribe-bar-views-option:not(.tribe-bar-active):hover, .tribe-events-list .type-tribe_events .event-content-wrapper .tribe-events-venue-details a:first-child:not(.tribe-events-gmap):hover, #tribe-mobile-container .type-tribe_events h4:hover, .tribe-events-week-grid .tribe-events-grid .tribe-grid-allday .tribe-events-week-allday-single h3.entry-title:hover a, .tribe-events-week-grid .tribe-events-grid .tribe-grid-body .tribe-events-week-hourly-single h3.entry-title:hover a, .tribe-organizer-wrapper .organizer-name a:hover, .tribe-events-back a:hover, .tribe-events-nav-pagination a:hover, .tribe-events-sub-nav a:hover, #user-registration.horizontal .user-registration-MyAccount-navigation ul li:not(.is-active) a:hover, .user-registration-info a, ol.commentlist .comment.bypostauthor .comment_postinfo span.fn, .divi-podcast-blog-box .blog-box-meta .entry-title:hover, .divi-podcast-categories-list ul li:not(.current-cat) a:hover, .podcast-box .podcast-box-meta .entry-title:hover {
            color: <?php esc_html_e($main_accent); ?> !important;
        }

        .primary-border-color, .primary-border-color, .give-form-wrap input[type=checkbox]:not(:disabled):hover:after, .give-form input[type=checkbox]:not(:disabled):hover:after, .give-form-wrap input[type=checkbox]:not(:disabled):hover:after, .give-form input[type=checkbox]:not(:disabled):hover:after, .give-form-wrap input[type=checkbox]:not(:disabled):hover:before, .give-form input[type=checkbox]:not(:disabled):hover:before, .give-form-wrap input[type=checkbox]:not(:disabled):hover:before, .give-form input[type=checkbox]:not(:disabled):hover:before, #tribe-events input[type=checkbox]:not(:disabled):hover:after, #tribe-bar-form input[type=checkbox]:not(:disabled):hover:after, #tribe-events input[type=checkbox]:not(:disabled):hover:after, #tribe-bar-form input[type=checkbox]:not(:disabled):hover:after, #tribe-events input[type=checkbox]:not(:disabled):hover:before, #tribe-bar-form input[type=checkbox]:not(:disabled):hover:before, #tribe-events input[type=checkbox]:not(:disabled):hover:before, #tribe-bar-form input[type=checkbox]:not(:disabled):hover:before, .divi-podcast-powerpress-player .powerpress_player .mejs-time-handle .mejs-time-handle-content, .divi-podcast-powerpress-player .powerpress_player .mejs-time-handle .mejs-time-handle-content, .ur-frontend-form input[type=checkbox]:not(:disabled):hover:after, .ur-frontend-form input[type=checkbox]:not(:disabled):hover:after, .ur-frontend-form input[type=checkbox]:not(:disabled):hover:before, .ur-frontend-form input[type=checkbox]:not(:disabled):hover:before, ol.commentlist .comment.bypostauthor .comment_avatar img, ol.commentlist .comment.bypostauthor .comment_avatar img {
            border-color: <?php esc_html_e($main_accent); ?> !important;
        }

        /*
         * Buttons
         */

        .divi-podcast-button, .et_pb_button.divi-podcast-button, body.et-db #et-boc .et-l .et_pb_button.divi-podcast-button, body.et-db #et-boc .divi-podcast-button.et_pb_button, body .divi-podcast-button.et_pb_button, .divi-podcast-pricing-table .et_pb_featured_table .et_pb_pricing_table_button, .give-form-wrap input[type=submit], .give-form-wrap button.give-btn-reveal, .give-form-wrap button.give-btn-modal, .give-form input[type=submit], .give-form button.give-btn-reveal, .give-form button.give-btn-modal, .ur-frontend-form input[type=submit], .ur-frontend-form button, .divi-podcast-contact-form button.et_pb_contact_submit, #sidebar .et_pb_widget.widget_search #searchsubmit, #sidebar .et_pb_widget.widget_product_search #searchsubmit, .divi-podcast-sidebar .et_pb_widget.widget_search #searchsubmit, .divi-podcast-sidebar .et_pb_widget.widget_search button, .divi-podcast-sidebar .et_pb_widget.widget_product_search #searchsubmit, .divi-podcast-sidebar .et_pb_widget.widget_product_search button {
            border-color: <?php esc_html_e($primary_button_border_color); ?> !important;
            color: <?php esc_html_e($primary_button_text_color ); ?> !important;
            background-color: <?php esc_html_e($primary_button_bg_color); ?> !important;
        }

        .divi-podcast-button:hover, .et_pb_button.divi-podcast-button:hover, body.et-db #et-boc .et-l .et_pb_button.divi-podcast-button:hover, body.et-db #et-boc .divi-podcast-button.et_pb_button:hover, body .divi-podcast-button.et_pb_button:hover, .divi-podcast-pricing-table .et_pb_featured_table .et_pb_pricing_table_button:hover, .give-form-wrap input[type=submit]:hover, .give-form-wrap button.give-btn-reveal:hover, .give-form-wrap button.give-btn-modal:hover, .give-form input[type=submit]:hover, .give-form button.give-btn-reveal:hover, .give-form button.give-btn-modal:hover, .ur-frontend-form input[type=submit]:hover, .ur-frontend-form button:hover, .divi-podcast-contact-form button.et_pb_contact_submit:hover, #sidebar .et_pb_widget.widget_search #searchsubmit:hover, #sidebar .et_pb_widget.widget_product_search #searchsubmit:hover, .divi-podcast-sidebar .et_pb_widget.widget_search #searchsubmit:hover, .divi-podcast-sidebar .et_pb_widget.widget_search button:hover, .divi-podcast-sidebar .et_pb_widget.widget_product_search #searchsubmit:hover, .divi-podcast-sidebar .et_pb_widget.widget_product_search button:hover {
            border-color: <?php esc_html_e($primary_button_hover_border_color); ?> !important;
            color: <?php esc_html_e($primary_button_hover_text_color); ?> !important;
            background-color: <?php esc_html_e($primary_button_hover_bg_color); ?> !important;
        }

        .divi-podcast-button-secondary, .et_pb_button.divi-podcast-button-secondary, body.et-db #et-boc .et-l .et_pb_button.divi-podcast-button-secondary, body.et-db #et-boc .divi-podcast-button-secondary.et_pb_button, body .divi-podcast-button-secondary.et_pb_button, .divi-podcast-newsletter .et_pb_newsletter_button, body.et-db #et-boc .et-l .divi-podcast-newsletter .et_pb_newsletter_button, .divi-popup-newsletter .et_pb_newsletter_button, .divi-podcast-pricing-table .et_pb_pricing_table_button, .give-form-wrap input.give-cancel-login, .give-form-wrap input.give-checkout-register-cancel, .give-form input.give-cancel-login, .give-form input.give-checkout-register-cancel, #tribe-events input[type=submit], #tribe-events button.button, #tribe-bar-form input[type=submit], #tribe-bar-form button.button, #tribe-mobile-container .type-tribe_events a.tribe-events-read-more, .ur-frontend-form input.give-cancel-login, .ur-frontend-form input.give-checkout-register-cancel, .ur-frontend-form.login p.user-registration-register.register a {
            border-color: <?php esc_html_e($secondary_button_border_color); ?> !important;
            color: <?php esc_html_e($secondary_button_text_color); ?> !important;
            background-color: <?php esc_html_e($secondary_button_bg_color); ?> !important;
        }

        .divi-podcast-button-secondary:hover, .et_pb_button.divi-podcast-button-secondary:hover, body.et-db #et-boc .et-l .et_pb_button.divi-podcast-button-secondary:hover, body.et-db #et-boc .divi-podcast-button-secondary.et_pb_button:hover, body .divi-podcast-button-secondary.et_pb_button:hover, .divi-podcast-newsletter .et_pb_newsletter_button:hover, body.et-db #et-boc .et-l .divi-podcast-newsletter .et_pb_newsletter_button:hover, .divi-popup-newsletter .et_pb_newsletter_button:hover, .divi-podcast-pricing-table .et_pb_pricing_table_button:hover, .give-form-wrap input.give-cancel-login:hover, .give-form-wrap input.give-checkout-register-cancel:hover, .give-form input.give-cancel-login:hover, .give-form input.give-checkout-register-cancel:hover, #tribe-events input[type=submit]:hover, #tribe-events button.button:hover, #tribe-bar-form input[type=submit]:hover, #tribe-bar-form button.button:hover, #tribe-mobile-container .type-tribe_events a.tribe-events-read-more:hover, .ur-frontend-form input.give-cancel-login:hover, .ur-frontend-form input.give-checkout-register-cancel:hover, .ur-frontend-form.login p.user-registration-register.register a:hover {
            border-color: <?php esc_html_e($secondary_button_hover_border_color); ?> !important;
            color: <?php esc_html_e($secondary_button_hover_text_color); ?> !important;
            background-color: <?php esc_html_e($secondary_button_hover_bg_color); ?> !important;
        }

        .divi-podcast-button, .et_pb_button.divi-podcast-button, body.et-db #et-boc .divi-podcast-button.et_pb_button, body .divi-podcast-button.et_pb_button, .divi-podcast-button-secondary, .et_pb_button.divi-podcast-button-secondary, body.et-db #et-boc .divi-podcast-button-secondary.et_pb_button, body .divi-podcast-button-secondary.et_pb_button, .divi-podcast-newsletter .et_pb_newsletter_button, .divi-popup-newsletter .et_pb_newsletter_button, .divi-podcast-pricing-table .et_pb_pricing_table_button, .divi-podcast-pricing-table .et_pb_featured_table .et_pb_pricing_table_button, .give-form-wrap input[type=submit], .give-form-wrap button.give-btn-reveal, .give-form-wrap button.give-btn-modal, .give-form input[type=submit], .give-form button.give-btn-reveal, .give-form button.give-btn-modal, .give-form-wrap input.give-cancel-login, .give-form-wrap input.give-checkout-register-cancel, .give-form input.give-cancel-login, .give-form input.give-checkout-register-cancel, #tribe-events input[type=submit], #tribe-events button.button, #tribe-bar-form input[type=submit], #tribe-bar-form button.button, #tribe-mobile-container .type-tribe_events a.tribe-events-read-more, .ur-frontend-form input[type=submit], .ur-frontend-form button, .ur-frontend-form input.give-cancel-login, .ur-frontend-form input.give-checkout-register-cancel, .ur-frontend-form.login p.user-registration-register.register a, .divi-podcast-contact-form button.et_pb_contact_submit, #sidebar .et_pb_widget.widget_search #searchsubmit, #sidebar .et_pb_widget.widget_product_search #searchsubmit, .divi-podcast-sidebar .et_pb_widget.widget_search #searchsubmit, .divi-podcast-sidebar .et_pb_widget.widget_search button, .divi-podcast-sidebar .et_pb_widget.widget_product_search #searchsubmit, .divi-podcast-sidebar .et_pb_widget.widget_product_search button {
            border-width: <?php esc_html_e($button_border_width); ?> !important;
            border-radius: <?php esc_html_e($button_radius); ?> !important;
            font-size: <?php esc_html_e($button_text_size); ?> !important;
        }

        /* underline button */
        .underlinePrimaryButton, .divi-podcast-event-top .recurringinfo a, .divi-podcast-powerpress-player .powerpress_links a, .ur-frontend-form.login p.user-registration-LostPassword.lost_password a, #user-registration .user-registration-MyAccount-content > p > a {
            font-size: <?php esc_html_e($button_text_size); ?> !important;
            color: <?php esc_html_e($primary_button_bg_color); ?> !important;
        }

        .underlinePrimaryButton:hover, .divi-podcast-event-top .recurringinfo a:hover, .divi-podcast-powerpress-player .powerpress_links a:hover, .ur-frontend-form.login p.user-registration-LostPassword.lost_password a:hover, #user-registration .user-registration-MyAccount-content > p > a:hover {
            color: <?php esc_html_e($primary_button_hover_bg_color); ?> !important;
        }

        /* Radio buttons */

        .give-form-wrap input[type=radio], .give-form input[type=radio], #tribe-events input[type=radio], #tribe-bar-form input[type=radio], .ur-frontend-form input[type=radio] {
            box-shadow: inset 0 0 0 2px <?php esc_html_e($fifth_accent); ?> !important;
        }

        .give-form-wrap input[type=radio]:checked, .give-form input[type=radio]:checked, #tribe-events input[type=radio]:checked, #tribe-bar-form input[type=radio]:checked, .ur-frontend-form input[type=radio]:checked {
            box-shadow: inset 0 0 0 5px <?php esc_html_e($main_accent); ?> !important;
        }

        /*
         * Box shadows
         */

        .navy-shadow-light, .bottom-shadow.bottom-shadow-dark:before, .divi-podcast-pricing-table .bottom-shadow-dark.et_pb_featured_table:before {
            box-shadow: 0 50px 60px -43px <?php esc_html_e($box_shadow_third); ?> !important;
        }

        .navy-shadow-medium {
            box-shadow: 0 40px 151px -19px <?php esc_html_e($box_shadow_third); ?> !important;
        }

        .navy-shadow-big {
            box-shadow: 0 2px 20px 2px <?php esc_html_e($box_shadow_third); ?> !important;
        }

        .secondary-shadow-big {
            box-shadow: 0 40px 151px -19px <?php esc_html_e($box_shadow_secondary); ?> !important;
        }

        .primary-shadow-light {
            box-shadow: 0 40px 151px -19px <?php esc_html_e($box_shadow_primary); ?> !important;
        }

        .primary-shadow-medium {
            box-shadow: 0 50px 60px -53px <?php esc_html_e($box_shadow_primary); ?> !important;
        }

        .primary-shadow-big {
            box-shadow: 0 40px 151px -19px <?php esc_html_e($box_shadow_primary); ?> !important;
        }

        .bottom-shadow.bottom-shadow-dark:before, .divi-podcast-pricing-table .bottom-shadow-dark.et_pb_featured_table:before {
            box-shadow: 0 50px 60px -43px <?php esc_html_e($box_shadow_third); ?> !important;
        }

        .bottom-shadow.bottom-shadow-primary:before, .divi-podcast-pricing-table .et_pb_featured_table:before {
            box-shadow: 0 50px 60px -43px <?php esc_html_e($box_shadow_primary); ?> !important;
        }

        .bottom-shadow.bottom-shadow-secondary:before, .divi-podcast-pricing-table .bottom-shadow-secondary.et_pb_featured_table:before {
            box-shadow: 0 50px 60px -43px <?php esc_html_e($box_shadow_secondary); ?> !important;
        }

        /*
         * Other
         */

        /* Border radius */
        .divi-podcast-borderRadius, .divi-podcast-borderRadiusImage img, .divi-podcast-menuPrimary ul.sub-menu, .divi-podcast-menuPrimary ul.et_mobile_menu, #top-menu li > ul.sub-menu, #et-secondary-nav li > ul.sub-menu, .mobile_nav ul.et_mobile_menu, .divi-podcast-menuPrimary ul.et_mobile_menu, #sidebar .et_pb_widget.widget_tag_cloud .tagcloud a, .divi-podcast-sidebar .et_pb_widget.widget_tag_cloud .tagcloud a, .et_pb_widget.widget_categories li a, .et_pb_widget.widget_archive li a, .divi-podcast-newsletter .et_pb_newsletter_result .et_pb_newsletter_error, .divi-popup-newsletter .et_pb_newsletter_result .et_pb_newsletter_error, .divi-podcast-newsletter .et_pb_newsletter_result .et_pb_newsletter_success, .divi-popup-newsletter .et_pb_newsletter_result .et_pb_newsletter_success, .divi-podcast-toggle, .et-db #et-boc .divi-podcast-toggle, .divi-podcast-tabs ul.et_pb_tabs_controls li a, .divi-podcast-pricing-table .et_pb_pricing_table, .wp-pagenavi span.current, .wp-pagenavi a, .wp-pagenavi .nextpostslink, .wp-pagenavi .previouspostslink, .give-form-wrap textarea, .give-form textarea, .give_error, .notice-dismiss, .give_success, .give_warning, .divi-podcast-donationForm, .mfp-content, .divi-podcast-donationForm .give-donation-levels-wrap button.give-donation-level-btn, .mfp-content .give-donation-levels-wrap button.give-donation-level-btn, #give_donation_receipt, #give_user_history, #tribe-events textarea, #tribe-bar-form textarea, .give_error, .tribe-events-notices, .give_success, .give_warning, .divi-podcast-event-top .tribe-events-cost, #tribe-bar-form #tribe-bar-filters-wrap, #tribe-bar-form #tribe-bar-views .tribe-bar-views-inner .tribe-bar-views-list, #tribe-bar-form #tribe-bar-collapse-toggle, #tribe-events-photo-events .tribe-events-photo-event .tribe-events-event-image img, .tribe-events-list .type-tribe_events, .tribe-events-list .type-tribe_events .event-thumb-wrapper .tribe-events-event-image img, #tribe-events-content table.tribe-events-calendar, #tribe-mobile-container .type-tribe_events, #tribe-mobile-container .type-tribe_events .tribe-events-event-image img, .tribe-events-week-grid .tribe-events-grid, #tribe-geo-map, .recurring-info-tooltip, .tribe-events-calendar .tribe-events-tooltip, .tribe-events-shortcode.view-week .tribe-events-tooltip, .tribe-events-week .tribe-events-tooltip, .recurring-info-tooltip .tribe-events-event-thumb img, .tribe-events-calendar .tribe-events-tooltip .tribe-events-event-thumb img, .tribe-events-shortcode.view-week .tribe-events-tooltip .tribe-events-event-thumb img, .tribe-events-week .tribe-events-tooltip .tribe-events-event-thumb img, .divi-podcast-powerpress-player .powerpress_player .mejs-horizontal-volume-total, .divi-podcast-powerpress-player .powerpress_player .mejs-time-buffering, .divi-podcast-powerpress-player .powerpress_player .mejs-time-current, .divi-podcast-powerpress-player .powerpress_player .mejs-time-float, .divi-podcast-powerpress-player .powerpress_player .mejs-time-float-corner, .divi-podcast-powerpress-player .powerpress_player .mejs-time-float-current, .divi-podcast-powerpress-player .powerpress_player .mejs-time-hovered, .divi-podcast-powerpress-player .powerpress_player .mejs-time-loaded, .divi-podcast-powerpress-player .powerpress_player .mejs-time-marker, .divi-podcast-powerpress-player .powerpress_player .mejs-time-total, .divi-podcast-subscribe-powerpress .pp-sub-widget, .ur-frontend-form textarea, #user-registration.horizontal .user-registration-MyAccount-navigation ul li a, .user-registration-error, .user-registration-info, .user-registration-message, .user-registration-password-strength, .divi-podcast-contact-form textarea, .divi-podcast-contact-form p textarea, ol.commentlist .comment .comment_avatar img, #commentform textarea, .divi-podcast-blog-box .post-wrapper, .divi-podcast-blog-box .thumb-wrapper, .divi-podcast-categories-list ul li a, .podcast-box, .podcast-box .thumb-wrapper {
            border-radius: <?php esc_html_e( $border_radius); ?> !important;
        }

        .divi-podcast-powerpress-player .powerpress_player .mejs-audio .mejs-playpause-button.mejs-play > button {
            background-image: url(<?php echo esc_html(get_theme_mod( 'podcast_play_icon', get_stylesheet_directory_uri() . '/images/play-icon.png' )); ?>) !important;
        }

        .divi-podcast-powerpress-player .powerpress_player .mejs-audio .mejs-playpause-button.mejs-replay > button {
            background-image: url(<?php echo esc_html(get_theme_mod( 'podcast_replay_icon', get_stylesheet_directory_uri() . '/images/replay-icon.png' )); ?>) !important;
        }

        .divi-podcast-powerpress-player .powerpress_player .mejs-audio .mejs-playpause-button.mejs-pause > button {
            background-image: url(<?php echo esc_html(get_theme_mod( 'podcast_stop_icon', get_stylesheet_directory_uri() . '/images/stop-icon.png' )); ?>) !important;
        }

        .divi-podcast-blog-box .thumb-wrapper.no-thumbnail {
            background-image: url(<?php echo esc_html(get_theme_mod( 'blog_no_thumb_icon', get_stylesheet_directory_uri() . '/images/blog_no_thumb.png' )); ?>) !important;
        }

    </style>

    <?php
}

add_action('wp_head', 'AGS_divi_podcast_customize_css');


// close php tag
?>