<?php
update_option (‘agstheme_divipodcast_license_key_status’, ‘valid’);
update_option (‘agstheme_divipodcast_license_key’, ‘*********’);
update_option (‘agstheme_divipodcast_license_key_expiry’, ‘2550450570’);
define('AGS_THEME_DIRECTORY', dirname(__FILE__) . '/');
define('AGS_THEME_VERSION',  wp_get_theme()->get('Version'));

/* Configure child theme */

function AGS_divi_podcast_configuration()
{
    // Stylesheets
    wp_enqueue_style('parent-style', get_template_directory_uri() . '/style.css');
    wp_deregister_style( 'divi-style' );
    wp_enqueue_style( 'divi-style', get_stylesheet_uri(), array(), AGS_THEME_VERSION);


    wp_enqueue_style('theme-css', get_stylesheet_directory_uri() . '/scss/app.css');

    // Scripts
    wp_enqueue_script('jquery');

    wp_register_script('nested-mobile-submenus', get_stylesheet_directory_uri() . '/js/nested-mobile-submenus.min.js');
    wp_enqueue_script('nested-mobile-submenus');

    wp_register_script('blog', get_stylesheet_directory_uri() . '/js/blog.min.js', array('jquery'), true);
    wp_enqueue_script('blog');

    wp_register_script('menu-items', get_stylesheet_directory_uri() . '/js/hide-menu-items.min.js', array('jquery'), true);
    wp_enqueue_script('menu-items');
}

add_action('wp_enqueue_scripts', 'AGS_divi_podcast_configuration');

/* Load translations */
add_action('after_setup_theme', function () {
    load_child_theme_textdomain('divipodcast', get_stylesheet_directory() . '/languages');
});


/* Include AGS admin functions */
include(AGS_THEME_DIRECTORY . 'admin/admin-functions.php');
include(AGS_THEME_DIRECTORY . 'admin/update-footer.php');

/*
 * Add child theme color scheme
 * Create new tab in wordpress customizer
 */

include(AGS_THEME_DIRECTORY . 'customizer/customizer_colors.php');

/*
 *  Create custom post types and taxonomies
 */

function AGS_divi_podcast_register_post_types()
{
    $labels = array(
        'name' => _x('Podcast', 'Post Type General Name', 'divipodcast'),
        'singular_name' => _x('Podcast', 'Post Type Singular Name', 'divipodcast'),
        'menu_name' => __('Podcasts', 'divipodcast'),
        'parent_item_colon' => __('Parent Podcast', 'divipodcast'),
        'all_items' => __('All Podcasts', 'divipodcast'),
        'view_item' => __('View Podcast', 'divipodcast'),
        'add_new_item' => __('Add New Podcast', 'divipodcast'),
        'add_new' => __('Add New', 'divipodcast'),
        'edit_item' => __('Edit Podcast', 'divipodcast'),
        'update_item' => __('Update Podcast', 'divipodcast'),
        'search_items' => __('Search Podcasts', 'divipodcast'),
        'not_found' => __('Not Found', 'divipodcast'),
        'not_found_in_trash' => __('No Podcasts found in Trash.', 'divipodcast'),
    );
    // Set other options for Custom Post Type
    $args = array(
        'labels' => $labels,
        'public' => true,
        'publicly_queryable' => true,
        'show_ui' => true,
        'show_in_menu' => true,
        'query_var' => true,
        'rewrite' => apply_filters('et_podcast_posttype_rewrite_args', array(
            'feeds' => true,
            'slug' => 'podcast',
            'with_front' => false,
        )),
        'capability_type' => 'post',
        'has_archive' => true,
        'menu_icon' => 'dashicons-microphone',
        'hierarchical' => false,
        'menu_position' => 6,
        'supports' => array('title', 'editor', 'author', 'thumbnail', 'excerpt', 'custom-fields')
    );
    // Registering your Custom Post Type
    register_post_type('podcast', $args);
}

add_action('init', 'AGS_divi_podcast_register_post_types', 0);


function AGS_divi_podcast_register_taxonomies()
{
    // Add new taxonomy, make it hierarchical (like categories)
    $labels = array(
        'name' => _x('Podcast Category', 'taxonomy general name', 'divipodcast'),
        'singular_name' => _x('Podcast Category', 'taxonomy singular name', 'divipodcast'),
        'search_items' => __('Search Categories', 'divipodcast'),
        'all_items' => __('All Categories', 'divipodcast'),
        'parent_item' => __('Parent Category', 'divipodcast'),
        'parent_item_colon' => __('Parent Category:', 'divipodcast'),
        'edit_item' => __('Edit Category', 'divipodcast'),
        'update_item' => __('Update Category', 'divipodcast'),
        'add_new_item' => __('Add New Category', 'divipodcast'),
        'new_item_name' => __('New Category Name', 'divipodcast'),
        'menu_name' => __('Podcast Category', 'divipodcast'),
    );
    $args = array(
        'hierarchical' => true,
        'labels' => $labels,
        'show_ui' => true,
        'show_admin_column' => true,
        'query_var' => true,
        'rewrite' => array('slug' => 'podcast-category'),
    );
    register_taxonomy('podcast-category', array('podcast'), $args);
}

add_action('init', 'AGS_divi_podcast_register_taxonomies', 0);

/*
 *  Register new sidebars
 */

function AGS_divi_podcast_register_new_widget()
{
    register_sidebar(array(
        'name' => esc_html__('Podcasts Sidebar', 'divipodcast'),
        'id' => 'sidebar-divi-podcast',
        'description' => __('Widgets in this area will be shown on all podcast archives.', 'divipodcast'),
        'before_widget' => '<div id="%1$s" class="et_pb_widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widgettitle">',
        'after_title' => '</h4>',
    ));
}

add_action('widgets_init', 'AGS_divi_podcast_register_new_widget');

/*
 *  Recent posts shortcode
 *
 */

function AGS_divi_podcast_recent_posts_shortcode($atts)
{
    ob_start();

    // define attributes and their defaults
    extract(shortcode_atts(array(
        'num' => '4',
        'cat' => '',
        'columns' => '4',
        'orderby' => 'date',
        'order' => 'DESC',
    ), $atts));

    // define query parameters based on attributes
    $options = array(
        'post__not_in' => array(get_the_ID()),
        'post_type' => 'post',
        'category_name' => $cat,
        'posts_per_page' => $num,
        'orderby' => $orderby,
        'order' => $order
    );

    if (!empty($columns)) {
        $columnsNumber = "col-" . $columns;
    } else {
        $columnsNumber = "col-4";
    }

    // Create a posts container
    echo '<div class="divi-podcast-recent-posts ' . esc_html($columnsNumber) . ' ">';

    $myquery = new WP_Query($options);

    // run the loop based on the query
    while ($myquery->have_posts()) : $myquery->the_post();
        get_template_part('templates/blog-box');
    endwhile;

    // Close posts container
    echo "</div> <!-- end .divi-podcast-recent-posts -->";

    $myvariable = ob_get_clean();
    return $myvariable;
}

add_shortcode('divi_podcast_recent_posts', 'AGS_divi_podcast_recent_posts_shortcode');

/* End code copied from digwp.com */

/*
 *  Recent podcasts shortcode
 *
 */

function AGS_divi_podcast_recent_podcasts_shortcode($atts)
{
    ob_start();

    // define attributes and their defaults
    extract(shortcode_atts(array(
        'num' => '5',
        'cat' => '',
        'orderby' => 'date',
        'order' => 'DESC',
        // 'columns' => '4',
    ), $atts));

    // define query parameters based on attributes
    $options = array(
        'post_type' => 'podcast',
        'post__not_in' => array(get_the_ID()),
        'category_name' => $cat,
        'posts_per_page' => $num,
        'orderby' => $orderby,
        'order' => $order
    );

    // Create a posts container
    echo '<div class="divi-podcast-recent-podcasts">';

    $myquery = new WP_Query($options);

    // run the loop based on the query
    while ($myquery->have_posts()) : $myquery->the_post();
        get_template_part('templates/podcast-box');
    endwhile;

    // Close posts container
    echo "</div> <!-- end .divi-podcast-recent-podcasts -->";

    $myvariable = ob_get_clean();
    return $myvariable;
}

add_shortcode('divi_podcast_recent_podcasts', 'AGS_divi_podcast_recent_podcasts_shortcode');

/*
 *  Tribe Events Calendar
 */

// Changes the escerpt length for events to 100 words
function AGS_divi_podcast_custom_excerpt_length($length)
{
    return function_exists('tribe_is_event') && tribe_is_event() && is_archive() ? 25 : $length;
}

add_filter('excerpt_length', 'AGS_divi_podcast_custom_excerpt_length', 999);


/*
 *  Remove archive labels.
 *
 *  Function below contains code from https://developer.wordpress.org/
 *  Copyright  WebMan Design | Oliver Juhas;
 *  @url https://developer.wordpress.org/reference/functions/get_the_archive_title/#comment-1807
 *
 *  Modified by Dominika Rauk; this file last modified 2019-12-16
 */

function AGS_divi_podcast_archive_title($title)
{
    if (is_category()) {
        $title = single_cat_title('', false);
    } elseif (is_tag()) {
        $title = single_tag_title('', false);
    } elseif (is_author()) {
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    } elseif (is_post_type_archive()) {
        $title = post_type_archive_title('', false);
    } elseif (is_tax()) {
        $title = single_term_title('', false);
    }

    return $title;
}

add_filter('get_the_archive_title', 'AGS_divi_podcast_archive_title');

/*
 *  Add body class when user is logged in or out.
 */

function AGS_divi_podcast_wp_body_classes($class)
{
    if (is_user_logged_in()) {
        $class[] = 'logged-in';
    } else {
        $class[] = 'logged-out';
    }
    return $class;
}

add_filter('body_class', 'AGS_divi_podcast_wp_body_classes');