<?php
/**
 *
 * This file contains code from the Tribe Events Calendar addon.
 *  Copyright Modern Tribe Inc; released under the GNU General Public License (GPL) version 2.
 *
 *
 * Day View Single Event
 * This file contains one event in the day view
 *
 * @version 4.6.19
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}

$venue_details = tribe_get_venue_details();

// Venue microformats
$has_venue         = ( $venue_details ) ? ' vcard' : '';
$has_venue_address = ( ! empty( $venue_details['address'] ) ) ? ' location' : '';

// The address string via tribe_get_venue_details will often be populated even when there's
// no address, so let's get the address string on its own for a couple of checks below.
$venue_address = tribe_get_address();
?>

    <div class="event-thumb-wrapper">
        <!-- Event Image -->
        <?php echo et_core_intentionally_unescaped(tribe_event_featured_image(null, 'medium'), 'html'); ?>

        <!-- Event Cost -->
        <?php if (tribe_get_cost()) : ?>
            <div class="tribe-events-event-cost">
                <span class="ticket-cost <?php if (tribe_get_cost() == 0) echo "free-ticket"; ?>"><?php echo esc_html(tribe_get_cost(null, true)); ?></span>
                <?php
                /**
                 * Runs after cost is displayed in list style views
                 *
                 * @since 4.5
                 */
                do_action('tribe_events_inside_cost')
                ?>
            </div>
        <?php endif; ?>
    </div>

    <div class="event-content-wrapper">

        <!-- Event Meta -->
        <?php do_action('tribe_events_before_the_meta') ?>
        <div class="tribe-events-event-meta">
            <div class="author <?php echo esc_attr($has_venue_address); ?>">

                <?php if ($venue_details) : ?>
                    <!-- Venue Display Info -->
                    <div class="tribe-events-venue-details">
                        <?php
                        $address_delimiter = empty($venue_address) ? ' ' : ', ';

                        // These details are already escaped in various ways earlier in the process.
                        // phpcs:ignore
                        echo implode($address_delimiter, $venue_details);

                        if (tribe_show_google_map_link()) {
                            echo et_core_intentionally_unescaped(tribe_get_map_link_html(), 'html');
                        }
                        ?>
                    </div> <!-- .atribe-events-venue-details -->
                <?php endif; ?>

                <!-- Schedule & Recurrence Details -->
                <div class="tribe-event-schedule-details">
                    <?php echo et_core_intentionally_unescaped(tribe_events_event_schedule_details(), 'html'); ?>
                </div>

            </div>
        </div><!-- .atribe-events-event-meta -->

        <!-- Event Title -->
        <?php do_action('tribe_events_before_the_event_title') ?>
        <h3 class="tribe-events-list-event-title">
            <a class="tribe-event-url" href="<?php echo esc_url(tribe_get_event_link()); ?>"
               title="<?php the_title_attribute() ?>" rel="bookmark">
                <?php the_title() ?>
            </a>
        </h3>
        <?php do_action('tribe_events_after_the_event_title') ?>

        <?php do_action('tribe_events_after_the_meta') ?>

        <!-- Event Content -->
        <?php do_action('tribe_events_before_the_content'); ?>
        <div class="tribe-events-list-event-description tribe-events-content description entry-summary">
            <?php
            // phpcs:ignore
            echo tribe_events_get_the_excerpt(null, wp_kses_allowed_html('post')); ?>
            <!--            <a href="-->
            <?php //echo esc_url(tribe_get_event_link()); ?><!--" class="atribe-events-read-more"-->
            <!--               rel="bookmark">-->
            <?php //esc_html_e('Find out more', 'the-events-calendar') ?><!-- &raquo;</a>-->
        </div><!-- .atribe-events-list-event-description -->

    </div>

<?php
do_action( 'tribe_events_after_the_content' );
